<?php
/**
 * Plugin Name: PIO - Express
 * Plugin URI: https://programmers.io/
 * Description: Upload your website logo on  WordPress login page instead of the WordPress logo with simple settings. Manage the wp admin show/hide for different roles. 
 * Version: 1.0
 * Author: Programmers.io
 * Author URI: https://programmers.io/
 */

if ( !defined( 'PIO_EXPRESS_PATH' ) )
define( 'PIO_EXPRESS_PATH', plugin_dir_url( __FILE__ ) );

//Add admin page to the menu
add_action( 'admin_menu', 'add_admin_page');
function add_admin_page() {
  // add top level menu page
  add_menu_page(
    'Pio Manager', //Page Title
    'PIO - Express', //Menu Title
    'manage_options', //Capability
    'pio-manage', //Page slug
    'managePageHandler' //Callback to print html
  );
}

//Admin page html callback
//Print out html for admin page
function managePageHandler() {
    // check user capabilities
    if ( ! current_user_can( 'manage_options' ) ) {
      return;
    }
    $manage_login_page = ( isset( $_GET['action'] ) && 'manage-login-page' == $_GET['action'] ) ? true : false;
    $manage_admin_bar = ( isset( $_GET['action'] ) && 'manage-admin-bar' == $_GET['action'] ) ? true : false;
    $faq = ( isset( $_GET['action'] ) && 'faq' == $_GET['action'] ) ? true : false;

  ?>
        
         <div class="wrap">
         <h1>PIO - Express Settings</h1>
         <h2 class="nav-tab-wrapper">
         <a href="<?php echo esc_url( add_query_arg( array( 'action' => 'manage-login-page' ), admin_url( 'admin.php?page=pio-manage' ) ) ); ?>" class="nav-tab <?php if ( (isset($_GET['action']) && 'manage-login-page' == $_GET['action']) || !isset($_GET['action']) ) echo ' nav-tab-active'; ?>"><?php esc_html_e( 'Manage Login Page' ); ?></a>

         <a href="<?php echo esc_url( add_query_arg( array( 'action' => 'manage-admin-bar' ), admin_url( 'admin.php?page=pio-manage' ) ) ); ?>" class="nav-tab <?php if ( isset($_GET['action']) && 'manage-admin-bar' == $_GET['action'] ) echo ' nav-tab-active'; ?>"><?php esc_html_e( 'Manage Admin Bar' ); ?></a> 

         <a href="<?php echo esc_url( add_query_arg( array( 'action' => 'faq' ), admin_url( 'admin.php?page=pio-manage' ) ) ); ?>" class="nav-tab <?php if ( isset($_GET['action']) && 'faq' == $_GET['action'] ) echo ' nav-tab-active'; ?>"><?php esc_html_e( 'FAQ' ); ?></a>
         </h2>
        <?php

        if($manage_login_page || !isset($_GET['action'])){
            changeLogoScreen();
        }
        elseif($manage_admin_bar){
            manageAdminBarScreen();
        }
        elseif($faq){
            faqScreen();
        }
        
        ?>
         
         </div> <?php
 
  }

  /**
   * Faq page screen handler
   */

   function faqScreen(){
    ?>  
<div class="wrap" style="width: 50%">
<label class="collapse" for="_1">Manage Login Page:</label>
<input id="_1" type="radio" name="c1" checked> 
<div class="contentdiv">
<h2>1. How does it work?</h2>
<ul>
<li>Click on the <strong>PIO &ndash; Express </strong>from the WP Admin Menu and then select the <strong>Manage Login Page.</strong></li>
<li>Click the upload logo button and select your desired logo.</li>
<li>Click on the save button. That&rsquo;s it. The selected logo will be visible on WP-Login Page</li>
</ul>
<h2>2. How to change the logo size?</h2>
<ul>
<li>You just need to enter the desired height and width in the given fields to change the logo size.</li>
</ul>
<h2>3. What is the recommended logo size?</h2>
<ul>
<li>The recommended logo size is 320px X 80px.</li>
</ul>
</div>
<label class="collapse" for="_2">Manage Admin Bar:</label>
<input id="_2" type="radio" name="c1">
<div class="contentdiv">
<h2>1. How does it work?</h2>
<ul>
<li>Click on the <strong>PIO &ndash; Express </strong>from the WP Admin Menu and then select the <strong>Manage Admin Bar.</strong></p>
<li>Check the All (Exclude Administrator)&nbsp;to hide the WP Admin Bar for the all roles except Administrator.</li>
<li>Check the For Administrator also to hide the WP Admin Bar for the administrator also.</li>
<li>Then click on the save button</li>
</ul>
</div>
<style>
.collapse{
    margin-bottom: 5px;
    cursor: pointer;
    display: block;
    font-size: 23px;
    line-height: 40px;
    border: 1px solid silver;
    border-radius: 10px;
    padding-left: 15px;
    position: relative;
    background: #e5e5e5;
}
.collapse:after {
  font-family: dashicons;
  
  content: "\f140";
  position: absolute;
  color: #868686;
  font-size: 18px;
  line-height: 22px;
  right: 20px;
  top: calc(50% - 10px);

}
.contentdiv{
  border: 1px dashed darkgrey;
    padding: 0px 15px;
    margin-bottom: 15px;
    border-radius: 5px;
    border-top: 0px;
}
.collapse + input{
  display: none; /* hide the checkboxes */
}
.collapse + input + div{
  display:none;
}
.collapse + input:checked + div{
  display:block;
}
</style>
</div>


    <?php
   }

  /**
   * Action Hook to perform
   * the hideadminbar action
   */
  add_action('after_setup_theme', 'remove_admin_bar');
 
  function remove_admin_bar() {
            if(get_option( 'pio_hide_wpadminbar' ) !==  false){
             
                $pio_hide_wpadminbar =get_option('pio_hide_wpadminbar');
                
                if(!empty($pio_hide_wpadminbar)){
                  $pio_hide_wpadminbar = json_decode($pio_hide_wpadminbar);
                if(isset($pio_hide_wpadminbar->for_all) && $pio_hide_wpadminbar->for_all){
                  show_admin_bar(false);
                }
                elseif(isset($pio_hide_wpadminbar->for_all_expt_admin) && $pio_hide_wpadminbar->for_all_expt_admin){
                  if (!current_user_can('administrator') && !is_admin()) {
                              show_admin_bar(false);
                             }
                }
              }

       }
     }


  /**
   * Function to show the 
   * adminbar options
   */

   function manageAdminBarScreen(){
    if(isset($_POST['action'])){
        if($_POST['action'] == "admin_bar_visiblity") {
          
          $pio_hide_wpadmin = $_POST['pio_hide_wpadminbar'];
          $dataArray = '';
          if(!empty($pio_hide_wpadmin)){
            $dataArray = array();
          foreach($pio_hide_wpadmin as $val){
            $dataArray[$val] = true;
          }
          $dataArray= json_encode($dataArray);
        }
          
            if(get_option( 'pio_hide_wpadminbar' ) !==  false){
                update_option( 'pio_hide_wpadminbar', $dataArray );
                ?> <div class="notice notice-success is-dismissible">
                  <p><?php _e('Updated succesfully!!!', 'textdomain') ?></p>
              </div>
              <?php
            }else{
                add_option( 'pio_hide_wpadminbar',  $dataArray, '', 'yes' );
                ?> <div class="notice notice-success is-dismissible">
                  <p><?php _e('Saved succesfully!!!', 'textdomain') ?></p>
              </div>
              <?php
            }

        }
        else{
            ?> <div class="notice notice-error is-dismissible">
                  <p><?php _e('Something went wrong!!!', 'textdomain') ?></p>
              </div>
              <?php
        }
    }
    $pio_hide_wpadminbar = get_option( 'pio_hide_wpadminbar' );
    $pio_hide_wpadminbar = json_decode($pio_hide_wpadminbar);
    ?>
    <div class='wrap' id='chnage_logo'>
      <h3 id='create-report'>Change Your Wp-Adminbar Visiblity Setting</h3>
      <form method ='post' enctype='multipart/form-data'>
      <input type="hidden" name="action" value="admin_bar_visiblity">
        <label><b>Hide Adminbar Only For :</b></label>
        <input type="checkbox" name="pio_hide_wpadminbar[]" value="for_all_expt_admin" id="for_all_expt_admin" 
        <?php echo  (isset($pio_hide_wpadminbar->for_all_expt_admin) && $pio_hide_wpadminbar->for_all_expt_admin) ? 'checked': '';  ?>>
        <label for="for_all_expt_admin">All (Exclude Administrator)</label> &nbsp; &nbsp; &nbsp; 
        <input type="checkbox" name="pio_hide_wpadminbar[]" value="for_all" id="for_all" 
        <?php echo  (isset($pio_hide_wpadminbar->for_all) && $pio_hide_wpadminbar->for_all) ? 'checked': '' ; ?>>
        <label for="for_all">For All Roles</label>
        <?php submit_button('Save');?>
      </form>
      <p><strong>Note: Check both boxes to hide menu bar for all users roles.</strong></p>
      </div>


    <?php

   }


/** Function to show the
 * logo updation options
 */

  function changeLogoScreen(){
    if(isset($_POST['action'])){
  
      if($_POST['action'] == "set_logo") {
       $logo_attachment_id = $_POST['logo_attachment_id'];
       $pio_logo_width = $_POST['pio_logo_width'];
       $pio_logo_height = $_POST['pio_logo_height'];

        if(get_option( 'pio_login_logo' ) !==  false){
          update_option( 'pio_login_logo', $logo_attachment_id );
         ?> <div class="notice notice-success is-dismissible">
                  <p><?php _e('Login Page updated succesfully!!!', 'textdomain') ?></p>
              </div>
              <?php 
              } else{
          add_option( 'pio_login_logo',  $logo_attachment_id, '', 'yes' );
          ?> <div class="notice notice-success is-dismissible">
                  <p><?php _e('Login Page updated succesfully!!!', 'textdomain') ?></p>
              </div>
              <?php
        }

        if(get_option( 'pio_logo_height' ) !==  false){
            update_option( 'pio_logo_height', $pio_logo_height );
        }else{
            add_option( 'pio_logo_height',  $pio_logo_height, '', 'yes' );
        }

        if(get_option( 'pio_logo_width' ) !==  false){
            update_option( 'pio_logo_width', $pio_logo_width );
        }else{
            add_option( 'pio_logo_width',  $pio_logo_width, '', 'yes' );
        }
        
      }
    }
  
  
  
    wp_enqueue_media();
    
      ?>
      <?php 
      
       ?>
      <div class='wrap' id='chnage_logo'>
      <h3 id='create-report'>Change Your Wp-Login Page Logo</h3>
      <form method ='post' enctype='multipart/form-data'>
      <input type="hidden" name="action" value="set_logo">
      
      <div class='image-preview-wrapper'>
              <img id='image-preview' src='<?php if(get_option( 'pio_login_logo' ) !==  false && !empty(get_option( 'pio_login_logo' ))) {
               echo wp_get_attachment_url( get_option( 'pio_login_logo' ) ); 
              }
              else{
                echo PIO_EXPRESS_PATH . 'assests/wordpress-logo.svg';
              }
               ?>' height='100'><br><br>
          </div>
     
          <input id="upload_image_button" type="button" class="button" value="<?php _e( 'Upload Logo' ); ?>" />
          <input type='hidden' name='logo_attachment_id' id='logo_attachment_id' value='<?php echo get_option( 'pio_login_logo' ); ?>'>
          <br> <br>
          <label><br>Height: </b></label>
          <input type="number" name="pio_logo_height" value="<?php echo get_option( 'pio_logo_height' ); ?>" min="10" >px
          <br> <br>
          <label><b>Width:</b> </label>
          <input type="number" name="pio_logo_width" value="<?php echo get_option( 'pio_logo_width' ); ?>" min="10" >px

      
      <?php submit_button('Save');?>
      </form>
      </div>
      <?php
  }

/**
 * To add the custom logo
 */
function updateLogo() { 
    if(get_option( 'pio_login_logo' ) !==  false && !empty(get_option( 'pio_login_logo' ))){
        $pio_logo_height = get_option('pio_logo_height','84');
		$pio_logo_width = get_option('pio_logo_width','84');
    ?> 
    <style type="text/css"> 
    body.login div#login h1 a {
     background-image: url(<?php echo wp_get_attachment_url( get_option( 'pio_login_logo' ) ); ?>); 
     background-size: <?=$pio_logo_width?>px <?=$pio_logo_height?>px;
     	height: <?=$pio_logo_height?>px; 
    width: <?=$pio_logo_width?>px;
    } 
    </style>
     <?php
    } 
    } add_action( 'login_enqueue_scripts', 'updateLogo' );

  /**
   * For Media Uploads in logo
   * Wordpress Media Integrated
   */
  add_action( 'admin_footer', 'media_selector_print_scripts' );

function media_selector_print_scripts() {

	$my_saved_attachment_post_id = get_option( 'media_selector_attachment_id', 0 );

	?><script type='text/javascript'>

		jQuery( document ).ready( function( $ ) {

			// Uploading files
			var file_frame;
			var wp_media_post_id = wp.media.model.settings.post.id; // Store the old id
			var set_to_post_id = <?php echo $my_saved_attachment_post_id; ?>; // Set this

			jQuery('#upload_image_button').on('click', function( event ){

				event.preventDefault();

				// If the media frame already exists, reopen it.
				if ( file_frame ) {
					// Set the post ID to what we want
					file_frame.uploader.uploader.param( 'post_id', set_to_post_id );
					// Open frame
					file_frame.open();
					return;
				} else {
					// Set the wp.media post id so the uploader grabs the ID we want when initialised
					wp.media.model.settings.post.id = set_to_post_id;
				}

				// Create the media frame.
				file_frame = wp.media.frames.file_frame = wp.media({
					title: 'Select a image to upload',
					button: {
						text: 'Use this image',
					},
					multiple: false	// Set to true to allow multiple files to be selected
				});

				// When an image is selected, run a callback.
				file_frame.on( 'select', function() {
					// We set multiple to false so only get one image from the uploader
					attachment = file_frame.state().get('selection').first().toJSON();

					// Do something with attachment.id and/or attachment.url here
					$( '#image-preview' ).attr( 'src', attachment.url ).css( 'width', 'auto' );
					$( '#logo_attachment_id' ).val( attachment.id );

					// Restore the main post ID
					wp.media.model.settings.post.id = wp_media_post_id;
				});

					// Finally, open the modal
					file_frame.open();
			});

			// Restore the main ID when the add media button is pressed
			jQuery( 'a.add_media' ).on( 'click', function() {
				wp.media.model.settings.post.id = wp_media_post_id;
			});
		});

	</script><?php
  

}